@@ -4,8 +4,8 @@ use warnings;
 use Test::More;
 use Data::Dumper;
 use WebDAO::Container;
-use WebDAO::Component;
-use base ( 'WebDAO::Container','WebDAO::Component' );
+use WebDAO;
+use base ( 'WebDAO::Container','WebDAO' );
 
 sub view {
     return 1
